<?php

namespace Ori\UniMessage\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Ori\UniMessage\Http\Requests\UniMessageUserRequest;
use Ori\UniMessage\Interfaces\UniMessageRepositoryInterface;
use Response;
use User;

class UniMessageUserController extends UserController
{
    /**
     * Initialize uni_message controller.
     *
     * @param type UniMessageRepositoryInterface $uni_message
     *
     * @return type
     */
    public function __construct(UniMessageRepositoryInterface $uni_message)
    {
        $this->model = $uni_message;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(UniMessageUserRequest $request)
    {
        $uni_messages = $this->model->all();

        $this->theme->prependTitle(trans('uni_message::uni_message.names').' :: ');

        return $this->theme->of('uni_message::user.uni_message.index', compact('uni_messages'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(UniMessageUserRequest $request, $role, $id)
    {
        $uni_message = $this->model->find($id);

        return $this->theme->of('uni_message::user.uni_message.show', compact('uni_message'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(UniMessageUserRequest $request)
    {
        $uni_message = $this->model->findOrNew(0);

        Former::populate($uni_message);

        return $this->theme->of('uni_message::user.uni_message.create', compact('uni_message'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(UniMessageUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $uni_message = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('uni_message::uni_message.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(UniMessageUserRequest $request, $role, $id)
    {
        $uni_message = $this->model->find($id);

        Former::populate($uni_message);

        return $this->theme->of('uni_message::user.uni_message.edit', compact('uni_message'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(UniMessageUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $uni_message = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('uni_message::uni_message.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(UniMessageUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('uni_message::uni_message.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
